@@ -1,3 +1,5 @@
+import { Observable, Subject } from "rxjs";
+import { filter, first, takeUntil } from "rxjs/operators";
 import { Injectable } from "@angular/core";
 import {
     extend,
@@ -10,7 +12,6 @@ import {
     TupleStorageFactoryService,
     VortexService,
     VortexStatusService,
-    TupleStorageBatchSaveArguments,
 } from "@synerty/vortexjs";
 
 import {
@@ -18,16 +19,17 @@ import {
     graphDbFilt,
     graphDbTuplePrefix,
 } from "../PluginNames";
-
-import { Observable, Subject } from "rxjs";
 import { EncodedSegmentChunkTuple } from "./EncodedSegmentChunkTuple";
 import { SegmentIndexUpdateDateTuple } from "./SegmentIndexUpdateDateTuple";
 import { GraphDbLinkedSegment } from "../../GraphDbLinkedSegment";
 import { GraphDbTupleService } from "../GraphDbTupleService";
 import { PrivateSegmentLoaderStatusTuple } from "./PrivateSegmentLoaderStatusTuple";
 
-import { OfflineConfigTuple } from "../tuples/OfflineConfigTuple";
 import { GraphDbPackedSegmentTuple } from "./GraphDbPackedSegmentTuple";
+import {
+    DeviceOfflineCacheControllerService,
+    OfflineCacheStatusTuple,
+} from "@peek/peek_core_device";
 
 // ----------------------------------------------------------------------------
 
@@ -131,32 +133,15 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
     private _statusSubject = new Subject<PrivateSegmentLoaderStatusTuple>();
     private _status = new PrivateSegmentLoaderStatusTuple();
 
-    private offlineConfig: OfflineConfigTuple = new OfflineConfigTuple();
-
     constructor(
         private vortexService: VortexService,
         private vortexStatusService: VortexStatusService,
         storageFactory: TupleStorageFactoryService,
-        private tupleService: GraphDbTupleService
+        private tupleService: GraphDbTupleService,
+        private deviceCacheControllerService: DeviceOfflineCacheControllerService
     ) {
         super();
 
-        this.tupleService.offlineObserver
-            .subscribeToTupleSelector(
-                new TupleSelector(OfflineConfigTuple.tupleName, {}),
-                false,
-                false,
-                true
-            )
-            .takeUntil(this.onDestroyEvent)
-            .filter((v) => v.length != 0)
-            .subscribe((tuples: OfflineConfigTuple[]) => {
-                this.offlineConfig = tuples[0];
-                if (this.offlineConfig.cacheChunksForOffline)
-                    this.initialLoad();
-                this._notifyStatus();
-            });
-
         this.storage = new TupleOfflineStorageService(
             storageFactory,
             new TupleOfflineStorageNameService(graphDbCacheStorageName)
@@ -165,10 +150,13 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
         this.setupVortexSubscriptions();
         this._notifyStatus();
 
-        // Check for updates every so often
-        Observable.interval(this.OFFLINE_CHECK_PERIOD_MS)
-            .takeUntil(this.onDestroyEvent)
-            .subscribe(() => this.askServerForUpdates());
+        this.deviceCacheControllerService.triggerCachingObservable
+            .pipe(takeUntil(this.onDestroyEvent))
+            .pipe(filter((v) => v))
+            .subscribe(() => {
+                this.initialLoad();
+                this._notifyStatus();
+            });
     }
 
     isReady(): boolean {
@@ -197,7 +185,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
             throw new Error("We've been passed a null/empty keys");
         }
 
-        if (!this.offlineConfig.cacheChunksForOffline) {
+        if (!this.deviceCacheControllerService.cachingEnabled) {
             let ts = new TupleSelector(GraphDbPackedSegmentTuple.tupleName, {
                 modelSetKey: modelSetKey,
                 keys: keys,
@@ -207,8 +195,8 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
                 .isOnline
                 ? Promise.resolve()
                 : this.vortexStatusService.isOnline
-                      .filter((online) => online)
-                      .first()
+                      .pipe(filter((online) => online))
+                      .pipe(first())
                       .toPromise();
 
             return isOnlinePromise
@@ -240,7 +228,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
             );
 
         return this.isReadyObservable()
-            .first()
+            .pipe(first())
             .toPromise()
             .then(() => this.getSegmentsWhenReady(modelSetKey, keys))
             .then((segments) => this._makeDictFromSegments(segments));
@@ -252,7 +240,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
 
     private _notifyStatus(): void {
         this._status.cacheForOfflineEnabled =
-            this.offlineConfig.cacheChunksForOffline;
+            this.deviceCacheControllerService.cachingEnabled;
         this._status.initialLoadComplete = this.index.initialLoadComplete;
 
         this._status.loadProgress = Object.keys(
@@ -264,6 +252,15 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
             ).length;
 
         this._statusSubject.next(this._status);
+
+        const status = new OfflineCacheStatusTuple();
+        status.pluginName = "peek_plugin_graphdb";
+        status.indexName = "Segment Index";
+        status.loadingQueueCount = this._status.loadProgress;
+        status.totalLoadedCount = this._status.loadTotal;
+        status.lastCheckDate = new Date();
+        status.initialFullLoadComplete = this._status.initialLoadComplete;
+        this.deviceCacheControllerService.updateCachingStatus(status);
     }
 
     /** Initial load
@@ -298,21 +295,21 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
                 this,
                 clientSegmentWatchUpdateFromDeviceFilt
             )
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
                 this.processSegmentsFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
         this.vortexStatusService.isOnline
-            .filter((isOnline) => isOnline == true)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(filter((isOnline) => isOnline == true))
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(() => this.askServerForUpdates());
     }
 
     private areWeTalkingToTheServer(): boolean {
         return (
-            this.offlineConfig.cacheChunksForOffline &&
+            this.deviceCacheControllerService.cachingEnabled &&
             this.vortexStatusService.snapshot.isOnline
         );
     }
@@ -374,7 +371,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
 
         for (let key of keysNeedingUpdate) {
             indexChunk.updateDateByChunkKey[key] =
-                this.index.updateDateByChunkKey[key];
+                this.index.updateDateByChunkKey[key] || "";
             count++;
 
             if (count == this.UPDATE_CHUNK_FETCH_SIZE) {
@@ -464,19 +461,26 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
      * Stores the index bucket in the local db.
      */
     private storeSegmentChunkTuples(
-        tuplesToSave: EncodedSegmentChunkTuple[]
+        encodedSegmentChunkTuples: EncodedSegmentChunkTuple[]
     ): Promise<void> {
-        const Selector = SegmentChunkTupleSelector;
-        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        let retPromise: any;
+        retPromise = this.storage.transaction(true).then((tx) => {
+            let promises = [];
 
-        for (const tuple of tuplesToSave) {
-            batchStore.push({
-                tupleSelector: new Selector(tuple.chunkKey),
-                vortexMsg: tuple.encodedData,
-            });
-        }
+            for (let encodedSegmentChunkTuple of encodedSegmentChunkTuples) {
+                promises.push(
+                    tx.saveTuplesEncoded(
+                        new SegmentChunkTupleSelector(
+                            encodedSegmentChunkTuple.chunkKey
+                        ),
+                        encodedSegmentChunkTuple.encodedData
+                    )
+                );
+            }
 
-        return this.storage.batchSaveTuplesEncoded(batchStore);
+            return Promise.all(promises).then(() => tx.close());
+        });
+        return retPromise;
     }
 
     /** Get Segments When Ready
